Coverage for girder/api/v1/docs/folder_docs: 100%

# Coverage for girder/api/v1/docs/folder_docs : 100%

## 7 statements 7 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 | #!/usr/bin/env python # -*- coding: utf-8 -*- ############################################################################### # Copyright 2013 Kitware Inc. # # Licensed under the Apache License, Version 2.0 ( the "License" ); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. ############################################################################### from ..api_docs import Describe apis = [] apis.append({ 'path': '/folder', 'resource': 'folder', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'findFolders', 'responseClass': 'Folder', 'summary': 'Search for folders by certain properties.', 'parameters': [ Describe.param( 'parentType', "Type of the folder's parent: either 'user', " "'folder', or 'collection' (default='folder').", required=False), Describe.param( 'parentId', "The ID of the folder's parent.", required=False), Describe.param( 'text', "Pass a full text search query.", required=False), Describe.param( 'limit', "Result set size limit (default=50).", required=False, dataType='int'), Describe.param( 'offset', "Offset into result set (default=0).", required=False, dataType='int'), Describe.param( 'sort', "Field to sort the folder list by (default=name)", required=False), Describe.param( 'sortdir', "1 for ascending, -1 for descending (default=1)", required=False, dataType='int') ], 'errorResponses': [ Describe.errorResponse(), Describe.errorResponse( 'Read access was denied on the parent resource.', 403) ] }, { 'httpMethod': 'POST', 'nickname': 'createFolder', 'responseClass': 'Folder', 'summary': 'Create a new folder.', 'parameters': [ Describe.param( 'parentType', "Type of the folder's parent: either 'user', " "'folder', or 'collection' (default='folder').", required=False), Describe.param('parentId', "The ID of the folder's parent."), Describe.param('name', "Name of the folder."), Describe.param('description', "Description of the folder.", required=False), Describe.param( 'public', "If the folder should be public or private. By " "default, inherits the value from parent folder, or in the " " case of user or collection parentType, defaults to False.", required=False, dataType='boolean') ], 'errorResponses': [ Describe.errorResponse(), Describe.errorResponse('Write access was denied on the parent', 403) ] }] }) apis.append({ 'path': '/folder/{folderId}', 'resource': 'folder', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'getFolderById', 'responseClass': 'Folder', 'summary': 'Get a folder by ID.', 'parameters': [ Describe.param( 'folderId', 'The ID of the folder.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Read access was denied for the folder.', 403) ] }, { 'httpMethod': 'DELETE', 'nickname': 'deleteFolderById', 'summary': 'Delete a folder by ID.', 'parameters': [ Describe.param( 'folderId', 'The ID of the folder.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Admin access was denied for the folder.', 403) ] }, { 'httpMethod': 'PUT', 'nickname': 'updateFolderById', 'summary': 'Update a folder by ID.', 'parameters': [ Describe.param( 'folderId', 'The ID of the folder.', paramType='path'), Describe.param('name', "Name of the folder."), Describe.param('description', "Description of the folder.", required=False), Describe.param( 'public', "If the folder should be public or private.", required=False, dataType='boolean') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Write access was denied for the folder.', 403) ] }] }) apis.append({ 'path': '/folder/{folderId}/access', 'resource': 'folder', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'getFolderAccess', 'responseClass': 'Folder', 'summary': 'Get the access control list for a folder.', 'parameters': [ Describe.param( 'folderId', 'The ID of the folder.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Admin access was denied for the folder.', 403) ] }, { 'httpMethod': 'PUT', 'nickname': 'updateFolderAccess', 'summary': 'Update the access control list for a folder.', 'parameters': [ Describe.param( 'folderId', 'The ID of the folder.', paramType='path'), Describe.param( 'access', 'The JSON-encoded access control list.'), Describe.param( 'public', 'Public access flag.', dataType='bool') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Admin access was denied for the folder.', 403) ] }] }) apis.append({ 'path': '/folder/{folderId}/download', 'resource': 'folder', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'downloadFolder', 'responseClass': 'Folder', 'summary': 'Download an entire folder as a zip archive.', 'parameters': [ Describe.param( 'folderId', 'The ID of the folder.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Read access was denied for the folder.', 403) ] }] }) Describe.declareApi('folder', apis=apis)